@@ -4,6 +4,6 @@ use warnings;
 
 use Perl::Metrics::Halstead ();
 
-my $pmh = Perl::Metrics::Halstead->new(file => 'lib/Perl/Metrics/Halstead.pm');
+my $pmh = Perl::Metrics::Halstead->new(file => $INC{'Perl/Metrics/Halstead.pm'});
 
 $pmh->report;
